package com.sun.imageio.plugins.gif;

import javax.imageio.metadata.IIOInvalidTreeException;
import javax.imageio.metadata.IIOMetadataNode;
import org.w3c.dom.Node;

public class GIFStreamMetadata extends GIFMetadata
{
    static final String nativeMetadataFormatName = "javax_imageio_gif_stream_1.0";
    static final String[] versionStrings;
    public String version;
    public int logicalScreenWidth;
    public int logicalScreenHeight;
    public int colorResolution;
    public int pixelAspectRatio;
    public int backgroundColorIndex;
    public boolean sortFlag;
    static final String[] colorTableSizes;
    public byte[] globalColorTable;
    
    protected GIFStreamMetadata(boolean b, String s, String s2, String[] array, String[] array2) {
        super(b, s, s2, array, array2);
        this.globalColorTable = null;
    }
    
    public GIFStreamMetadata() {
        this(true, "javax_imageio_gif_stream_1.0", "com.sun.imageio.plugins.gif.GIFStreamMetadataFormat", null, (String[])null);
    }
    
    @Override
    public boolean isReadOnly() {
        return true;
    }
    
    @Override
    public Node getAsTree(String s) {
        if (s.equals("javax_imageio_gif_stream_1.0")) {
            return this.getNativeTree();
        }
        if (s.equals("javax_imageio_1.0")) {
            return this.getStandardTree();
        }
        throw new IllegalArgumentException("Not a recognized format!");
    }
    
    private Node getNativeTree() {
        IIOMetadataNode iioMetadataNode = new IIOMetadataNode("javax_imageio_gif_stream_1.0");
        IIOMetadataNode newChild = new IIOMetadataNode("Version");
        newChild.setAttribute("value", this.version);
        iioMetadataNode.appendChild(newChild);
        IIOMetadataNode newChild2 = new IIOMetadataNode("LogicalScreenDescriptor");
        newChild2.setAttribute("logicalScreenWidth", (this.logicalScreenWidth == -1) ? "" : Integer.toString(this.logicalScreenWidth));
        newChild2.setAttribute("logicalScreenHeight", (this.logicalScreenHeight == -1) ? "" : Integer.toString(this.logicalScreenHeight));
        newChild2.setAttribute("colorResolution", (this.colorResolution == -1) ? "" : Integer.toString(this.colorResolution));
        newChild2.setAttribute("pixelAspectRatio", Integer.toString(this.pixelAspectRatio));
        iioMetadataNode.appendChild(newChild2);
        if (this.globalColorTable != null) {
            IIOMetadataNode newChild3 = new IIOMetadataNode("GlobalColorTable");
            int i = this.globalColorTable.length / 3;
            newChild3.setAttribute("sizeOfGlobalColorTable", Integer.toString(i));
            newChild3.setAttribute("backgroundColorIndex", Integer.toString(this.backgroundColorIndex));
            newChild3.setAttribute("sortFlag", this.sortFlag ? "TRUE" : "FALSE");
            for (int j = 0; j < i; ++j) {
                IIOMetadataNode newChild4 = new IIOMetadataNode("ColorTableEntry");
                newChild4.setAttribute("index", Integer.toString(j));
                int k = this.globalColorTable[3 * j] & 0xFF;
                int l = this.globalColorTable[3 * j + 1] & 0xFF;
                int m = this.globalColorTable[3 * j + 2] & 0xFF;
                newChild4.setAttribute("red", Integer.toString(k));
                newChild4.setAttribute("green", Integer.toString(l));
                newChild4.setAttribute("blue", Integer.toString(m));
                newChild3.appendChild(newChild4);
            }
            iioMetadataNode.appendChild(newChild3);
            return iioMetadataNode;
        }
        return iioMetadataNode;
    }
    
    public IIOMetadataNode getStandardChromaNode() {
        IIOMetadataNode iioMetadataNode = new IIOMetadataNode("Chroma");
        IIOMetadataNode newChild = new IIOMetadataNode("ColorSpaceType");
        newChild.setAttribute("name", "RGB");
        iioMetadataNode.appendChild(newChild);
        IIOMetadataNode newChild2 = new IIOMetadataNode("BlackIsZero");
        newChild2.setAttribute("value", "TRUE");
        iioMetadataNode.appendChild(newChild2);
        if (this.globalColorTable != null) {
            IIOMetadataNode newChild3 = new IIOMetadataNode("Palette");
            for (int n = this.globalColorTable.length / 3, i = 0; i < n; ++i) {
                IIOMetadataNode newChild4 = new IIOMetadataNode("PaletteEntry");
                newChild4.setAttribute("index", Integer.toString(i));
                newChild4.setAttribute("red", Integer.toString(this.globalColorTable[3 * i] & 0xFF));
                newChild4.setAttribute("green", Integer.toString(this.globalColorTable[3 * i + 1] & 0xFF));
                newChild4.setAttribute("blue", Integer.toString(this.globalColorTable[3 * i + 2] & 0xFF));
                newChild3.appendChild(newChild4);
            }
            iioMetadataNode.appendChild(newChild3);
            IIOMetadataNode newChild5 = new IIOMetadataNode("BackgroundIndex");
            newChild5.setAttribute("value", Integer.toString(this.backgroundColorIndex));
            iioMetadataNode.appendChild(newChild5);
            return iioMetadataNode;
        }
        return iioMetadataNode;
    }
    
    public IIOMetadataNode getStandardCompressionNode() {
        IIOMetadataNode iioMetadataNode = new IIOMetadataNode("Compression");
        IIOMetadataNode newChild = new IIOMetadataNode("CompressionTypeName");
        newChild.setAttribute("value", "lzw");
        iioMetadataNode.appendChild(newChild);
        IIOMetadataNode newChild2 = new IIOMetadataNode("Lossless");
        newChild2.setAttribute("value", "TRUE");
        iioMetadataNode.appendChild(newChild2);
        return iioMetadataNode;
    }
    
    public IIOMetadataNode getStandardDataNode() {
        IIOMetadataNode iioMetadataNode = new IIOMetadataNode("Data");
        IIOMetadataNode newChild = new IIOMetadataNode("SampleFormat");
        newChild.setAttribute("value", "Index");
        iioMetadataNode.appendChild(newChild);
        IIOMetadataNode newChild2 = new IIOMetadataNode("BitsPerSample");
        newChild2.setAttribute("value", (this.colorResolution == -1) ? "" : Integer.toString(this.colorResolution));
        iioMetadataNode.appendChild(newChild2);
        return iioMetadataNode;
    }
    
    public IIOMetadataNode getStandardDimensionNode() {
        IIOMetadataNode iioMetadataNode = new IIOMetadataNode("Dimension");
        IIOMetadataNode newChild = new IIOMetadataNode("PixelAspectRatio");
        float f = 1.0f;
        if (this.pixelAspectRatio != 0) {
            f = (float)(this.pixelAspectRatio + 15) / 64.0f;
        }
        newChild.setAttribute("value", Float.toString(f));
        iioMetadataNode.appendChild(newChild);
        IIOMetadataNode newChild2 = new IIOMetadataNode("ImageOrientation");
        newChild2.setAttribute("value", "Normal");
        iioMetadataNode.appendChild(newChild2);
        IIOMetadataNode newChild3 = new IIOMetadataNode("HorizontalScreenSize");
        newChild3.setAttribute("value", (this.logicalScreenWidth == -1) ? "" : Integer.toString(this.logicalScreenWidth));
        iioMetadataNode.appendChild(newChild3);
        IIOMetadataNode newChild4 = new IIOMetadataNode("VerticalScreenSize");
        newChild4.setAttribute("value", (this.logicalScreenHeight == -1) ? "" : Integer.toString(this.logicalScreenHeight));
        iioMetadataNode.appendChild(newChild4);
        return iioMetadataNode;
    }
    
    public IIOMetadataNode getStandardDocumentNode() {
        IIOMetadataNode iioMetadataNode = new IIOMetadataNode("Document");
        IIOMetadataNode newChild = new IIOMetadataNode("FormatVersion");
        newChild.setAttribute("value", this.version);
        iioMetadataNode.appendChild(newChild);
        return iioMetadataNode;
    }
    
    public IIOMetadataNode getStandardTextNode() {
        return null;
    }
    
    public IIOMetadataNode getStandardTransparencyNode() {
        return null;
    }
    
    @Override
    public void setFromTree(String s, Node node) throws IIOInvalidTreeException {
        throw new IllegalStateException("Metadata is read-only!");
    }
    
    @Override
    protected void mergeNativeTree(Node node) throws IIOInvalidTreeException {
        throw new IllegalStateException("Metadata is read-only!");
    }
    
    @Override
    protected void mergeStandardTree(Node node) throws IIOInvalidTreeException {
        throw new IllegalStateException("Metadata is read-only!");
    }
    
    @Override
    public void reset() {
        throw new IllegalStateException("Metadata is read-only!");
    }
    
    static {
        versionStrings = new String[] { "87a", "89a" };
        colorTableSizes = new String[] { "2", "4", "8", "16", "32", "64", "128", "256" };
    }
}
